Authors
=======

Hydra (ndn-hydra) is a mutli-unviersity project between UCLA and TTU.

* Sankalpa Timilsina   <https://github.com/sankalpatimilsina12>
* Gabriel Porteiro     <https://github.com/GportDev> 
* Justin Presley       <https://github.com/justincpresley>
* Zixuan Zhong         <https://github.com/ZixuanZhong>
* Tianyuan Yu          <https://github.com/tianyuan129
* Varun Patil          <https://github.com/pulsejet>
* Daniel Achee         <https://github.com/daniel-achee>
* Alex Afanasyev       <https://github.com/cawka>
* Susmit Shannigrahi   <https://github.com/tntech-ngin>
